export type PermissionSection = "club" | "configuration" | "management";

export type PermissionModule =
  | "member"
  | "calendar"
  | "newsletter"
  | "newsletter_config"
  | "protocol"
  | "listprint"
  | "qualification"
  | "award"
  | "executive_position"
  | "communication_type"
  | "membership_status"
  | "salutation"
  | "calendar_type"
  | "user"
  | "role"
  | "webapi"
  | "query"
  | "query_store"
  | "template"
  | "template_usage"
  | "backup";

export type PermissionType = "read" | "create" | "update" | "delete";

export type PermissionString =
  | `${PermissionSection}.${PermissionModule}.${PermissionType}` // für spezifische Berechtigungen
  | `${PermissionSection}.${PermissionModule}.*` // für alle Berechtigungen in einem Modul
  | `${PermissionSection}.${PermissionType}` // für spezifische Berechtigungen in einem Abschnitt
  | `${PermissionSection}.*` // für alle Berechtigungen in einem Abschnitt
  | "*"; // für Admin

export type PermissionObject = {
  [section in PermissionSection]?: {
    [module in PermissionModule]?: Array<PermissionType> | "*";
  } & { all?: Array<PermissionType> | "*" };
} & {
  admin?: boolean;
};

export type SectionsAndModulesObject = {
  [section in PermissionSection]: Array<PermissionModule>;
};

export const permissionSections: Array<PermissionSection> = ["club", "configuration", "management"];
export const permissionModules: Array<PermissionModule> = [
  "member",
  "calendar",
  "newsletter",
  "newsletter_config",
  "protocol",
  "listprint",
  "qualification",
  "award",
  "executive_position",
  "communication_type",
  "membership_status",
  "salutation",
  "calendar_type",
  "user",
  "role",
  "webapi",
  "query",
  "query_store",
  "template",
  "template_usage",
  "backup",
];
export const permissionTypes: Array<PermissionType> = ["read", "create", "update", "delete"];
export const sectionsAndModules: SectionsAndModulesObject = {
  club: ["member", "calendar", "newsletter", "protocol", "query", "listprint"],
  configuration: [
    "qualification",
    "award",
    "executive_position",
    "communication_type",
    "membership_status",
    "salutation",
    "calendar_type",
    "query_store",
    "template",
    "template_usage",
    "newsletter_config",
  ],
  management: ["user", "role", "webapi", "backup"],
};
